@@ -7,8 +7,9 @@ def latexdisplayunits(varname,varval,units,roundto=3):
     return display(Latex('$' + varname + '= $' + str(round(varval,roundto)) + ' $' + units + '$'))
 
 def variablename(var):
-    import itertools
-    return str(([tpl[0] for tpl in filter(lambda x: var is x[1], globals().items())])[0])
+    # import itertools
+    # return str(([tpl[0] for tpl in filter(lambda x: var is x[1], globals().items())])[0])
+    return str([tpl[0] for tpl in filter(lambda x: var is x[1], globals().items())][0])
 
 def brint(var,units='',roundto=3):
     if units == '':
